@@ -127,7 +127,10 @@ def ph_args():
     return parser.parse_args()
 
 
-def main_ph():
+# https://github.com/daveshap/RecursiveSummarizer/blob/main/recursively_summarize.py
+
+
+def phmain(self):
     user_input = " ".join(args.question)
 
     if args.paste:  # Paste the copy buffer
